--------------------------
-- Repro: Orphan a User --
--------------------------

/*
Process: 
	1.Create a login "OliverTwist"**.
	2.Create a database.
	3.Create a user in that database from the "OliverTwist" login.
	4.Back up the database, then drop it.
	5.Drop the login.
	6.Restore the database.

Then you should have an orphan.

http://www.MidnightDBA.com/Jen 
*/

USE master;
GO
--------------------------------
-- 1.Create a login "OliverTwist"
CREATE LOGIN OliverTwist WITH PASSWORD='CanIHaveSomeMore?';
GO

--------------------------------
-- 2.Create a database.
IF EXISTS ( SELECT  *
            FROM    sys.databases
            WHERE   name = 'OrphanedUserDemo' ) 
    DROP DATABASE OrphanedUserDemo;
GO

CREATE DATABASE OrphanedUserDemo;
GO

--------------------------------
-- 3.Create a user in that database from the "OliverTwist" login.
USE OrphanedUserDemo;
GO
CREATE USER OliverTwist FROM LOGIN OliverTwist;
GO

--------------------------------
-- 4.Back up the database, then drop it.
USE master;
GO
BACKUP DATABASE OrphanedUserDemo TO DISK = 'c:\temp\OrphanedUserDemo.bak' WITH FORMAT, INIT;
GO
DROP DATABASE OrphanedUserDemo;
GO

--------------------------------
-- 5.Drop the login.
DROP LOGIN OliverTwist;
GO

--------------------------------
-- 6.Restore the database.

RESTORE DATABASE OrphanedUserDemo FROM DISK = 'c:\temp\OrphanedUserDemo.bak';
GO


--------------------------------
-- Check for orphaned users:
EXEC OrphanedUserDemo..sp_change_users_login 'Report';
GO


/*
--------------------------------
-- Here is the fix for this one orphaned user:

CREATE LOGIN OliverTwist WITH PASSWORD='CanIHaveSomeMore?';
GO
EXEC OrphanedUserDemo..sp_change_users_login 'AUTO_FIX', 'OliverTwist';
GO
EXEC OrphanedUserDemo..sp_change_users_login 'Report';
GO
*/



/*

-- CLEANUP --

USE master;
GO
DROP DATABASE OrphanedUserDemo;
GO
DROP LOGIN OliverTwist;

*/





